@@ -330,7 +330,16 @@ class Scraper(): #threading.Thread):
         if not 'allowed_domains' in url_data:
             log( "'allowed_domains' not found in URL dictionary, setting to []" )
             url_data['allowed_domains'] = []
-        
+
+        print "\n"
+        print type(url_data['max_link_level'])
+        print "\n"
+
+        # if the data is being supplied by a CSV max_link_level can end up as a string
+        # we'll test for this, and convert to a number
+        if isinstance(url_data['max_link_level'], str) \
+                or isinstance(url_data['max_link_level'], unicode):
+            url_data['max_link_level'] = int(url_data['max_link_level'])
 
         # set the url data local
         self.status['url_data'] = url_data
@@ -415,7 +424,7 @@ class Scraper(): #threading.Thread):
 
         isodatetime = strftime("%Y-%m-%d %H:%M:%S")
         packet = {
-            'docurl': doc_url,
+            'doc_url': doc_url,
             'link_text': link_text,
             'url_data': self.status['url_data'],
             'scrape_datetime': str(isodatetime)
